@@ -80,12 +80,12 @@ sub new {
 		);
 	}
 
-	DEBUG( 100,"CREATE context $self" );
+	DEBUG( 100,"CREATE context $self callid=$self->{callid}" );
 	return $self
 }
 
 sub DESTROY {
-	DEBUG( 100,"DESTROY context $_[0]" );
+	DEBUG( 100,"DESTROY context $_[0] callid=$_[0]->{callid}" ) if $_[0];
 }
 
 ############################################################################
@@ -249,7 +249,7 @@ sub handle_response {
 		if ( $t->{tid} eq $tid ) {
 			$tr = $t;
 		} else {
-			push @ntrans,$tr
+			push @ntrans,$t
 		}
 	}
 	$tr || do {
